aurora/build_scripts/base
renner a76fa2e80c
refactor: faster kernel installation with a shim (#2926)
This is taken from [1]. We were for no good reason regenerating the initramfs
here. We can also install the kmods with the kernel in one step so I
don't see why we shouldn't just do that. It reduces the amount of time
needed to run this script (on my machine) from 49s to 28s.

I'm not sure if this is an oversight in rpm-ostree, we could technically
use the initramfs that is built during this stage, however, we lose
quite a bit of control, which we definitively want to have.

Also it should generally be noticable when the v4l2 and xone kmods fail
to install. There also haven't been problem regarding that in quite a
while.

[1] 5441c76f1f
2026-09-27 05:34:12 +00:00
..
01-packages.sh chore: remove intel-vpl-gpu-rt from overrides (#2930) 2026-09-25 12:50:21 +00:00
02-install-common-kernel-akmods.sh refactor: faster kernel installation with a shim (#2926) 2026-09-27 05:34:12 +00:00
03-fetch.sh refactor: repurpose build.sh as build preparation (#2701) 2026-08-09 19:11:44 +00:00
04-nvidia.sh feat: rename build_files to build_scripts (#2691) 2026-08-09 05:58:24 +00:00
16-override-install.sh chore: remove cjk font symlink (#2909) 2026-09-23 04:21:22 +00:00
17-cleanup.sh chore: remove ZFS (#2918) 2026-09-25 15:05:12 +00:00
18-image-info.sh feat: rename build_files to build_scripts (#2691) 2026-08-09 05:58:24 +00:00
19-initramfs.sh feat: rename build_files to build_scripts (#2691) 2026-08-09 05:58:24 +00:00
20-tests.sh chore: remove ZFS (#2918) 2026-09-25 15:05:12 +00:00